@@ -1,3 +1,6 @@
+use utf8;
+use warnings;
+no warnings 'redefine';
 use vars qw(@t $ff $ss $folderfirst $sortstate);
 $folderfirst = param('folderfirst') ? 1 : 0;
 $ss          = param('sort')        ? 1 : 0;
@@ -113,7 +116,7 @@ sub _rec {
     for (my $i = 0 ; $i < @$tree ; $i++) {
         if (defined @$tree[$i]) {
             my $text = defined @$tree[$i]->{text} ? @$tree[$i]->{text} : '';
-            if (defined @{@$tree[$i]->{subtree}}) {
+            if (ref @{@$tree[$i]->{subtree}}  eq "HASH" ) {
                 print
                   "#FOLDER\n\tID=@$tree[$i]->{rid}\n\tNAME=$text\n\tUNIQUEID=@$tree[$i]->{rid}\n";
                 _rec(\@{@$tree[$i]->{subtree}});
