@@ -1,3 +1,5 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
 use vars qw(@menuNavi);
 @menuNavi = $m_oDatabase->fetch_AoH(
@@ -5,11 +7,12 @@ use vars qw(@menuNavi);
 );
 print q(<?xml version="1.0" encoding="UTF-8"?><actions>);
 for (my $i = 0 ; $i < $#menuNavi ; $i++) {
-    print qq(action output="$menuNavi->{output}">
-		<title>$menuNavi->{title}</title>
-		<xml>cgi-bin/mysql.pl?action=$menuNavi->{action}</xml>
-		<out>content</out>
-		<id>$menuNavi->{action}</id>
-		<text>$menuNavi->{title}</text>
-	</action>);
+print qq(<action output="$menuNavi->{output}">
+    <title>$menuNavi->{title}</title>
+    <xml>cgi-bin/mysql.pl?action=$menuNavi->{action}</xml>
+    <out>content</out>
+    <id>$menuNavi->{action}</id>
+    <text>$menuNavi->{title}</text>
+</action>);
 }
+1;
\ No newline at end of file
