@@ -1,59 +1,59 @@
 $VAR1 = {
-          'floodtime' => 10,
+          'size' => '16',
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'cgi' => {
-                     'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'bin' => '/var/www/cgi-bin',
-                     'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
-                     'serverName' => 'http://localhost',
-                     'cookiePath' => '/'
-                   },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'saveTranslate' => '0',
-          'htmlright' => '2',
-          'uploads' => {
-                         'path' => '/var/www/htdocs//download',
-                         'enabled' => 1,
-                         'right' => 2,
-                         'maxlength' => '2100000000000000',
-                         'chmod' => 438
-                       },
-          'version' => '1.02',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'news' => {
+                      'captcha' => 3,
+                      'messages' => '5',
+                      'right' => 5
+                    },
+          'files' => {
+                       'group' => 'lze',
+                       'owner' => 'lze',
+                       'chmod' => '0755'
+                     },
+          'version' => '1.03',
           'admin' => {
                        'password' => 'testpass'
                      },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'files' => {
-                       'chmod' => '0755',
-                       'owner' => 'lze',
-                       'group' => 'lze'
-                     },
-          'database' => {
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'MySQLAdmin',
-                          'password' => '',
-                          'host' => 'localhost',
-                          'CurrentHost' => 'localhost',
-                          'name' => 'MySQLAdmin',
-                          'CurrentPass' => '',
-                          'user' => 'root'
-                        },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'language' => 'en',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'uploads' => {
+                         'enabled' => 1,
+                         'right' => 2,
+                         'maxlength' => '2100000000000000',
+                         'path' => '/var/www/htdocs//download',
+                         'chmod' => 438
+                       },
+          'floodtime' => 10,
+          'session' => '/var/www/cgi-bin/config/session.pl',
           'mod' => 'n',
-          'news' => {
-                      'messages' => '5',
-                      'right' => 5,
-                      'captcha' => 3
-                    },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'language' => 'en',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'saveTranslate' => '0',
+          'htmlright' => '2',
+          'defaultAction' => 'ShowDatabases',
+          'database' => {
+                          'password' => '',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'host' => 'localhost',
+                          'name' => 'MySQLAdmin',
+                          'CurrentUser' => 'root',
+                          'CurrentPass' => '',
+                          'user' => 'root',
+                          'CurrentHost' => 'localhost'
+                        },
           'tree' => {
                       'navigation' => '/var/www/cgi-bin/config/tree.pl',
                       'links' => '/var/www/cgi-bin/config/links.pl'
                     },
-          'size' => '16',
-          'defaultAction' => 'ShowDatabases'
+          'cgi' => {
+                     'expires' => '+1y',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'cookiePath' => '/',
+                     'serverName' => 'http://localhost',
+                     'bin' => '/var/www/cgi-bin',
+                     'style' => 'mysql',
+                     'title' => 'MySQL::Admin'
+                   }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
