@@ -36,7 +36,7 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
         qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '1.02';
+$DBI::Library::Database::VERSION = '1.03';
 $m_nSecs                         = 10;
 
 =head1 NAME
@@ -61,7 +61,7 @@ sub new {
     return $self;
 }
 
-=head2 getName()
+=head2 getName
 
       $name = $m_oDatabase->getName($m_sSid);
 
@@ -132,9 +132,9 @@ sub checkSession {
     return $return;
 }
 
-=head2 checkPass()
-
+=head2 checkPass
 
+  bool checkPass( user, crypt_pass);
 
 =cut
 
@@ -156,7 +156,7 @@ sub checkPass {
 
 =head2 right()
 
-      $nRight = right($m_sAction,$sUsername);
+  $nRight = right($m_sAction,$sUsername);
 
 =cut
 
